from subprocess import CalledProcessError
from subprocess import check_call


__all__ = ["get_bootstrap_failure_hint"]


def get_bootstrap_failure_hint(msg):
    """
    Check input message and return a guess of the root cause of error.

    Parameters
    ----------
    msg : string
        A message string. It is often stdout or stderr returned by a subprocess command.

    Returns
    -------
    string
        The description of possible failure root cause.

    """
    rtn_msg_prefix = "Failed for:"
    if (
        "cannot start bootstrap instance: failed to acquire node" in msg
        and "No such tag" in msg
    ):
        return f"{rtn_msg_prefix} not finding nodes with specified tags. You may want to check your bootstrap constraint."
    elif "bootstrap instance started but did not change to Deployed state" in msg:
        return f"{rtn_msg_prefix} bootstrap instance started but did not change to Deployed state."
    elif "failed to acquire node: No available machine matches constraints.":
        return f"{rtn_msg_prefix} failed to acquire node: No available machine matches constraints."
    else:
        return f"{rtn_msg_prefix} unknown reason."


def if_controller():
    cmd = ["/bin/su", "-", "jenkins", "-c", "juju controllers"]
    try:
        check_call(cmd)
        return True

    except CalledProcessError:
        return False
